InternalImportRule class final

「この層ディレクトリのファイルは、どの層を import してよいか」の宣言。

dirPatternNamingRuleEntity.dirPattern と同じ流儀の層パス (パスセグメント単位で照合)。自層(同じ dirPattern に属するパス)への import は常に許可される。層ディレクトリの外(core/main.dart 等、 どの層にも属さないパス)への import は監査対象外。

Constructors

InternalImportRule({required String dirPattern, List<String> allow = const []})
const

Properties

allow List<String>
import してよい層パスのリスト(ホワイトリスト)。
final
dirPattern String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited