MsgId class final

Inheritance

Constructors

MsgId(String value)
const
MsgId.forDate(DateTime date, int seq)
date: yyyyMMdd、seq: その日の連番(1始まり)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

matches(String raw) bool