ImplScanResult class final
doc/impl/ 走査の結果。
Constructors
-
ImplScanResult({Map<
String, ImplPlanMeta> byPath = const {}, List<String> unreadable = const [], Map<String, List< duplicates = const {}})String> > -
const
Properties
-
byPath
→ Map<
String, ImplPlanMeta> -
プロジェクト相対パス → メタ
final
-
duplicates
→ Map<
String, List< String> > -
同じ ID を持つファイルが複数ある場合の「ID → パス一覧」。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isHealthy → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
unreadable
→ List<
String> -
frontmatter が読めなかったファイル(相対パス)。
一覧から消えるだけでなく ID 再利用の温床になるので、必ず報告する。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited